﻿using Microsoft.Win32;
using Syncfusion.Data;
using Syncfusion.UI.Xaml.Grid;
using Syncfusion.UI.Xaml.Grid.Helpers;
using Syncfusion.UI.Xaml.TreeGrid;
using Syncfusion.UI.Xaml.TreeGrid.Filtering;
using Syncfusion.Windows.Shared;
using Syncfusion.Windows.Shared.Resources;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Globalization;
using System.IO;
using System.Linq;
using System.Printing;
using System.Text;
using System.Threading;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace SfDataGrid_Net
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            //Used to set the AdvancedFilterType while open the FilterPopup.
            this.sftreeGrid.FilterItemsPopulating += OnSfTreeGridFilterItemsPopulating;
            //CustomSorting used to perform the sorting.
            this.sftreeGrid.SortComparers.Add(new SortComparer() { Comparer = new CustomSortComparer(), PropertyName = "OrderDate" });

        }
        private void OnSfTreeGridFilterItemsPopulating(object sender, TreeGridFilterItemsPopulatingEventArgs e)
        {
            if (e.Column.MappingName == "OrderDate")
                e.FilterControl.AdvancedFilterType = AdvancedFilterType.DateFilter;
        }
        private void dataGrid_AutoGeneratingColumn_1(object sender, TreeGridAutoGeneratingColumnEventArgs e)
        {
            if (e.Column.MappingName == "OrderDate")
            {
                e.Column = new TreeGridDateTimeColumn()
                {
                    AllowNullValue = true,
                    MappingName = "OrderDate",
                    Pattern = DateTimePattern.CustomPattern,
                    CustomPattern = "dd.MM.yyyy",
                    AllowFiltering = true
                };
            }
        }
        public class CustomSortComparer : IComparer<object>, ISortDirection
        {

            //Custom Sorting for date.
            public int Compare(object x, object y)
            {
                var item1 = x as OrderInfo;
                var item2 = y as OrderInfo;
                DateTime dateTime1;
                bool isDone = DateTime.TryParse(item1.OrderDate, out dateTime1);
                DateTime dateTime2;
                bool isDone1 = DateTime.TryParse(item2.OrderDate, out dateTime2);
                
                int c = 0;

                if (dateTime1 != null && dateTime2 == null)
                {
                    c = 1;
                }

                else if (dateTime1 == null && dateTime2 != null)
                {
                    c = -1;
                }

                else if (dateTime1 != null && dateTime2 != null)
                {
                    c = DateTime.Compare(dateTime1, dateTime2);
                }

                if (SortDirection == ListSortDirection.Descending)
                    c = -c;

                return c;
            }

            //Get or Set the SortDirection value
            private ListSortDirection _SortDirection;

            public ListSortDirection SortDirection
            {
                get { return _SortDirection; }
                set { _SortDirection = value; }
            }
        }
    }

}
